@@ -3,7 +3,6 @@ Tests for content parsing, and form-overloaded content parsing.
 """
 import copy
 import os.path
-import sys
 import tempfile
 
 import pytest
@@ -375,9 +374,5 @@ class TestDeepcopy(TestCase):
 
 
 class TestTyping(TestCase):
-    @pytest.mark.skipif(
-        sys.version_info < (3, 7),
-        reason="subscriptable classes requires Python 3.7 or higher",
-    )
     def test_request_is_subscriptable(self):
         assert Request is Request["foo"]
