@@ -1,7 +1,6 @@
 import inspect
 import pickle
 import re
-import sys
 from collections import ChainMap
 from collections.abc import Mapping
 
@@ -205,10 +204,6 @@ class TestSerializer:
                 exceptions.ErrorDetail(string='Raised error', code='invalid')
             ]}
 
-    @pytest.mark.skipif(
-        sys.version_info < (3, 7),
-        reason="subscriptable classes requires Python 3.7 or higher",
-    )
     def test_serializer_is_subscriptable(self):
         assert serializers.Serializer is serializers.Serializer["foo"]
 
@@ -743,10 +738,6 @@ class TestDeclaredFieldInheritance:
 
 
 class Test8301Regression:
-    @pytest.mark.skipif(
-        sys.version_info < (3, 9),
-        reason="dictionary union operator requires Python 3.9 or higher",
-    )
     def test_ReturnDict_merging(self):
         # Serializer.data returns ReturnDict, this is essentially a test for that.
 
